@@ -40,6 +40,8 @@ struct _MetaTabEntry
   int              x, y, width, height;
   int              inner_x, inner_y, inner_width, inner_height;
   guint            blank : 1;
+  guint            hidden : 1;
+  guint            demands_attention : 1;
 };
 
 MetaTabPopup*   meta_ui_tab_popup_new          (const MetaTabEntry *entries,
